import { Component, OnInit } from '@angular/core';
import { AlertController, NavController } from '@ionic/angular';
import * as Parse from "parse"

@Component({
  selector: 'app-login',
  templateUrl: './login.page.html',
  styleUrls: ['./login.page.scss'],
})
export class LoginPage implements OnInit {

  username: string = ""
  password: string = ""
  
  constructor(
    private navCtrl: NavController,
    private alertController: AlertController
  ) { }

  ngOnInit() { }

  async login() {
    let user;
    try {
      user = await Parse.User.logIn(this.username, this.password);
    } catch (error: any) {
      let message: string = "";
      if (error?.message.indexOf("is required") > -1) {
        message = "必须输入账号或邮箱";
      }
      if (error?.message.indexOf("Invalid username") > -1) {
        message = "账号或密码错误，请检查";
      }
      this.presentAlert({
        header: "登录失败",
        subHeader: "状态码:" + error.code,
        message: message || error.message
      });
    }
    console.log(user);
    if (user?.id) {
      this.navCtrl.navigateForward('/tabs/tab3'); // 修改这里
    }
  }

  async register() {
    let user = new Parse.User();
    user.set("username", this.username);
    user.set("password", this.password);
    try {
      let result = await user.signUp();
      console.log(result);
      if (result?.id) {
        this.navCtrl.navigateForward('/tabs/tab3'); // 修改这里
      }
    } catch (error: any) {
      let message: string = "";
      if (error?.message.indexOf("already exists") > -1) {
        message = "该账号已存在请修改后重试";
      }
      if (error?.message.indexOf("empty") > -1) {
        message = "账号不能为空请输入后重试";
      }
      this.presentAlert({
        header: "注册失败",
        subHeader: "状态码:" + error.code,
        message: message || error.message
      });
    }
  }

  async presentAlert(options: { header: string, subHeader: string, message: string }) {
    const alert = await this.alertController.create({
      header: options?.header,
      subHeader: options?.subHeader,
      message: options?.message,
      buttons: ['好的'],
    });

    await alert.present();
  }

  back() {
    this.navCtrl.back();
  }
}
